@@ -9,9 +9,9 @@ use WWW::Discogs;
 my $discogs = WWW::Discogs->new(apikey => '5b4bea98ec');
 if (my $artist = $discogs->artist('Ween')) {
 	for (@{ $artist->releases }) {
-		my $release = $discogs->release($_);
+		my $release = $discogs->release($_->{id});
 		if ($release->images) {
-			print $release->title . "\n". $release->images->[0] . "\n\n";
+			print $release->title . "\n". $release->images->[0]{uri} . "\n\n";
 		}
 	}
 }
