@@ -9,6 +9,6 @@ use WWW::Discogs;
 my $discogs = WWW::Discogs->new(apikey => '5b4bea98ec');
 if (my $artist = $discogs->artist('Ween')) {
 	for (@{ $artist->images }) {
-		print "$_\n";
+		print "$_->{uri}\n";
 	}
 }
