@@ -7,13 +7,13 @@ use lib '../lib';
 use WWW::Discogs;
 
 my $discogs = WWW::Discogs->new(apikey => '5b4bea98ec');
-for my $result (@{ $discogs->search('Ween','artist') }) {
+my $search = $discogs->search('Bill Callahan');
+for my $result (@{ $search->exactresults }) {
 	if ($result->{type} eq 'artist') {
 		my $artist = $discogs->artist($result->{title});
-		print $artist->name . "\n";
 		if ($artist->images) {
-			print $artist->images->[0] . "\n";
+			print $artist->name . "\n";
+			print $artist->images->[0]{uri} . "\n\n";
 		}
-		print "\n";
 	}
 }
